diff --git a/core/res/res/values/config.xml b/core/res/res/values/config.xml
index 3ac5df6ba9150..219a416c5c80a 100644
--- a/core/res/res/values/config.xml
+++ b/core/res/res/values/config.xml
@@ -2418,8 +2418,8 @@
5
900000
-
- false
+
+ false
false
@@ -2657,9 +2657,9 @@
will be locked. -->
false
-
- false
+
+ false
diff --git a/core/java/android/provider/Settings.java b/core/java/android/provider/Settings.java
index 4ec38f7415e1a..e5c654a13357d 100644
--- a/core/java/android/provider/Settings.java
+++ b/core/java/android/provider/Settings.java
@@ -10309,11 +10309,11 @@ public final class Settings {
public static final String QS_AUTO_ADDED_TILES = "qs_auto_tiles";
/**
* The duration of timeout, in milliseconds, to switch from a non-primary user to the
* primary user when the device is docked.
* @hide
*/
- public static final String TIMEOUT_TO_USER_ZERO = "timeout_to_user_zero";
+ public static final String TIMEOUT_TO_DOCK_USER = "timeout_to_dock_user";
/**
* Backup manager behavioral parameters.
@@ -10309,11 +10309,11 @@ public final class Settings {
public static final String QS_AUTO_ADDED_TILES = "qs_auto_tiles";
/**
- * The duration of timeout, in milliseconds, to switch from a non-primary user to the
- * primary user when the device is docked.
+ * The duration of timeout, in milliseconds, to switch from a non-Dock User to the
+ * Dock User when the device is docked.
* @hide
*/